/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief Example template project.
* @defgroup nrf_templates_example Example template
* @{
* @ingroup nrf_examples_nrf6310
*
* @brief Example template.
*
*/

#include "nrf51.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"

// Counter is in 32kHz ticks. (NRF_WDT->CRV + 1)/32768 seconds
#define WATCHDOG_COUNTER        32768
#define MY_LED                  18


void init_watchdog(void)
{
    NRF_WDT->CONFIG = (WDT_CONFIG_SLEEP_Run << WDT_CONFIG_SLEEP_Pos);
    NRF_WDT->CRV = WATCHDOG_COUNTER;    
    NRF_WDT->RREN = WDT_RREN_RR0_Enabled << WDT_RREN_RR0_Pos;
    NRF_WDT->TASKS_START = 1;
}

int main(void)
{
    nrf_gpio_cfg_output(MY_LED);
    nrf_gpio_pin_set(MY_LED);
    nrf_delay_us(1000*1000);
    init_watchdog();
    nrf_gpio_pin_clear(MY_LED);
    while (1)
    {
        // Reload WD. LED will light up 1 second upon RESET.
        NRF_WDT->RR[0] = WDT_RR_RR_Reload;
    }
}
/**
 *@}
 **/
